@@ -440,9 +440,9 @@ class DatabaseManager:
             return False
         print(f"\n{_csu.gen.title_divider('Equari Database Tables')}\n\n")
         table:_table_manager.TableManager
-        for table in self.data['tables']:
+        for table in self.table_instances:
             tables.append(table.table_name)
-            print(_Fore.RED + f"    {_csu.rightPad(table.schema(),self.data['longest_schema_name'],' ')}" + _Fore.CYAN + f" - {table.table_name}" + _Style.RESET_ALL)
+            print(_Fore.RED + f"    {_csu.rightPad(table.schema,self.data['longest_schema_name'],' ')}" + _Fore.CYAN + f" - {table.table_name}" + _Style.RESET_ALL)
         print(f"Total Tables: {len(self.data['tables'])}")
         print(f"\n\n{_csu.gen.title_divider('Equari Database Tables')}\n\n")
         return tables
@@ -906,6 +906,9 @@ class DatabaseManager:
         return self.settings['create_dir']
 
 
+    @property
+    def table_instances(self)->_Iterable[_table_manager.TableManager]:
+        return self.data['tables_instances']
     @property
     def tables(self)->_Iterable[dict]:
         '''
@@ -1793,6 +1796,9 @@ def database_from_summary(summary_path:str,**kwargs)->_Union[DatabaseManager,boo
             Automatically check if the master.sql has changed and parse it to the directory structure.
             If this is False, it will not do this.
 
+        [`auto_purge`=True] {bool}
+            Automatically delete table directories that do not exist in the master SQL
+
         [`verbose`=False] {bool}
             Make it a chatty kathy.
 
