@@ -688,7 +688,7 @@ class TableManager:
 
 
 
-    def insert_data(self,data):
+    def insert_data(self,data,overwrite=False):
         '''
             Insert a new row or rows into the default data json file.
 
@@ -701,9 +701,12 @@ class TableManager:
                 Keys must correspond to the column in the table, they are case sensitive.
                 This does `NOT` type match the columns, so if you fuck it up, its on you.
 
-            Return {type}
+            [`overwrite`=False] {bool}
+                If True, the existing data is overwritten by the new data.
+
+            Return {bool}
             ----------------------
-            return_description
+            True upon success, false otherwise.
 
             Meta
             ----------
@@ -714,9 +717,9 @@ class TableManager:
             `method_name`: insert_default_data
             * @xxx [06-01-2022 15:16:46]: documentation for insert_default_data
         '''
-        return self.default_data_manager.set_insert_data(data)
+        return self.default_data_manager.set_insert_data(data,overwrite=overwrite)
 
-    def insert_test_data(self,data):
+    def insert_test_data(self,data,overwrite=False):
         '''
             Insert a new row or rows into the test_data json file.
 
@@ -729,6 +732,9 @@ class TableManager:
                 Keys must correspond to the column in the table, they are case sensitive.
                 This does `NOT` type match the columns, so if you fuck it up, its on you.
 
+            [`overwrite`=False] {bool}
+                If True, the existing data is overwritten by the new data.
+
             Return {type}
             ----------------------
             return_description
@@ -742,7 +748,7 @@ class TableManager:
             `method_name`: insert_default_data
             * @xxx [06-01-2022 15:16:46]: documentation for insert_default_data
         '''
-        return self.test_data_manager.set_insert_data(data)
+        return self.test_data_manager.set_insert_data(data,overwrite=overwrite)
 
 
 
@@ -991,7 +997,19 @@ class TableManager:
 
 
         data = self.import_default_json_data()
-        return len(data) + 1
+        if isinstance(data,(list)):
+            return len(data) + 1
+        else:
+            return 1
+
+    @property
+    def next_test_id(self):
+        data = self.main.insert_data['test'][self.name]
+        # data = self.import_default_json_data()
+        if isinstance(data,(list)):
+            return len(data) + 1
+        else:
+            return 1
 
     @property
     def primary(self):
