@@ -4,41 +4,31 @@
 # pylint: disable=unused-wildcard-import
 # pylint: disable=wildcard-import
 # pylint: disable=unused-import
-# '''
-#     A module of utility methods used for parsing SQL code.
+'''
+    A module of utility methods used for parsing SQL code.
 
-#     ----------
+    ----------
 
-#     Meta
-#     ----------
-#     `author`: Colemen Atwood
-#     `created`: 06-03-2022 10:04:06
-#     `memberOf`: parse_sql
-#     `version`: 1.0
-#     `method_name`: parse_sql
-# '''
-
-# from utils.string_utils.string_conversion import bool_to_int,bool_to_string,to_bool
-from utils.dict_utils.dict_utils import get_kwarg as _get_kwarg
-from utils.dict_utils.dict_utils import set_defaults as _set_defaults
-from utils.list_utils.list_utils import append as _append
-from utils.string_utils.string_format import strip_any as _strip_any
-from utils.string_utils.string_format import strip_empty_lines as _strip_empty_lines
-from utils.file_utils.file_utils import exists as _file_exists
-from utils.file_utils.file_read import read as _read_file
+    Meta
+    ----------
+    `author`: Colemen Atwood
+    `created`: 06-03-2022 10:04:06
+    `memberOf`: parse_sql
+    `version`: 1.0
+    `method_name`: parse_sql
+'''
 
 
-
-
-
-import re
-import shlex
-import sqlparse
+import re as _re
+import shlex as _shlex
+import sqlparse as _sqlparse
 from pyparsing import And, Suppress,Dict, Word, Literal, Group, Optional, ZeroOrMore, OneOrMore, Regex, restOfLine, alphanums,nums, printables, string, CaselessKeyword,nestedExpr,ParseException,quotedString,removeQuotes,originalTextFor,delimitedList,QuotedString
-# import utils.files.file as cfu
-# # from sqlparse import sql
-# import utils.string_format as mod
-# import utils.object_utils as obj
+
+import utils.dict_utils as _obj
+import utils.list_utils as _lu
+import utils.string_utils as _csu
+import utils.file_utils as _f
+
 
 _sql_data_types = [
     "mediumtext",
@@ -166,8 +156,6 @@ def drop_table(table_name,schema_name=None,if_exists=True,quote_char="`"):
         exist_string = " IF EXISTS"
     return f'''DROP TABLE{exist_string} {schema_string}`{table_name}`;'''
 
-
-
 def _gen_column_string(columns):
     '''
         Generate the SQL list of column names.
@@ -325,9 +313,6 @@ def _get_all_columns(data):
             if name not in columns:
                 columns.append(name)
     return columns
-    # return columns.sort()
-
-
 
 def insert_sql(data,table_name,schema_name=None):
     '''
@@ -371,7 +356,7 @@ def insert_sql(data,table_name,schema_name=None):
                 "timestamp":123456789,
             }
         ]
-        sql = csu.gen.sql.insert_sql(data,'kitties','titties')
+        sql = _csu.gen.sql.insert_sql(data,'kitties','titties')
 
         ============================== return ==============================
 
@@ -427,7 +412,6 @@ def insert_sql(data,table_name,schema_name=None):
             return sql
     return False
 
-
 def sql_type_to_python(value):
     '''
         Attempts to convert an sql type to its python equivalent.
@@ -494,8 +478,6 @@ def sql_type_to_python(value):
     if value in _sql_data_types:
         return _sql_data_types[value]
     return None
-    # if value == ""
-
 
 def strip_comments(value):
     '''
@@ -522,7 +504,7 @@ def strip_comments(value):
         @xxx [03-21-2022 12:29:07]: documentation for strip_comments
     '''
 
-    value = re.sub(r'--[^\n]*\n','',value)
+    value = _re.sub(r'--[^\n]*\n','',value)
     return value
 
 def strip_sql_quotes(sql):
@@ -560,7 +542,6 @@ def strip_sql_quotes(sql):
     sql = sql.replace('`','')
     return sql
 
-
 def escape_quoted_commas(value,escape_value="__ESCAPED_COMMA__",reverse=False):
     '''
         Escape commas that are located within quotes.
@@ -665,7 +646,6 @@ def escape_quoted_chars(value,reverse=False):
     # print(sql_qs.search_string(value))
     return value
 
-
 def parse_column_data(value=None):
     
     # value = "`timestamp`       int NULL DEFAULT NULL COMMENT 'Timestamp of when the task was created.' ,"
@@ -730,19 +710,16 @@ def parse_column_data(value=None):
                     new_data['allow_nulls'] = True
                     continue
             if isinstance(v,(list)):
-                v = _strip_any(v[0],["'",'"'])
+                v = _csu.strip(v[0],["'",'"'])
                 new_data[k] = v
                 continue
             new_data[k] = v
 
         # print(new_data)
-        new_data = _set_defaults(defaults,new_data)
+        new_data = _obj.set_defaults(defaults,new_data)
         output = new_data
     return output
 
-
-
-
 def parse_schema_statement(value=None):
     
     # value = "CREATE SCHEMA IF NOT EXISTS `idealech_Equari_Content_Database`;"
@@ -783,13 +760,11 @@ def parse_schema_statement(value=None):
                 new_data[k] = v[0]
                 continue
             new_data[k] = v
-        new_data = _set_defaults(defaults,new_data)
+        new_data = _obj.set_defaults(defaults,new_data)
         # print(new_data)
         output = new_data
     return output
 
-
-
 def parse_table_statement(value=None):
     
     # value = "DROP TABLE IF EXISTS `idealech_Equari_Management_Database`.`blackholes`;"
@@ -833,10 +808,10 @@ def parse_table_statement(value=None):
                 new_data[k] = v[0]
                 continue
             new_data[k] = v
-        new_data = _set_defaults(defaults,new_data)
+        new_data = _obj.set_defaults(defaults,new_data)
         if new_data['action'] == "create":
             cols = capture_create_table_columns(value)
-            # new_data['column_data'] = obj.strip_list_nulls([parse_column_data(x) for x in cols])
+            # new_data['column_data'] = _obj.strip_list_nulls([parse_column_data(x) for x in cols])
             d = _parse_table_column_lines(cols)
             new_data["columns"] = d['columns']
             new_data["primary_keys"] = d['primary_keys']
@@ -860,17 +835,17 @@ def _parse_table_column_lines(lines):
         # print(f"line: {line}")
         if is_line_key(line):
             # print(f"key found: {line} {parse_key(line)}")
-            data['keys'] = _append(data['keys'],parse_key(line))
+            data['keys'] = _lu.append(data['keys'],parse_key(line))
             pk = parse_primary_key(line)
             if pk is not None:
-                data['primary_keys'] = _append(data['primary_keys'],pk['primary_key'])
-            # data['primary_keys'] = _append(data['primary_keys'],parse_primary_key(line))
+                data['primary_keys'] = _lu.append(data['primary_keys'],pk['primary_key'])
+            # data['primary_keys'] = _lu.append(data['primary_keys'],parse_primary_key(line))
 
         if is_line_constraint(line):
-            data['constraints'] = _append(data['constraints'],parse_constraint(line))
+            data['constraints'] = _lu.append(data['constraints'],parse_constraint(line))
 
 
-        data['columns'] = _append(data['columns'],parse_column_data(line))
+        data['columns'] = _lu.append(data['columns'],parse_column_data(line))
 
         # parse_column_data(line)
     # data['keys'] = keys
@@ -909,13 +884,10 @@ def capture_create_table_columns(sql):
     output = []
     scanner = originalTextFor(nestedExpr('(',')'))
     for match in scanner.searchString(sql):
-        val = _strip_any(match[0],["(",")"])
+        val = _csu.strip(match[0],["(",")"])
         val = escape_quoted_chars(val,True)
         output = val.split("\n")
     return output
-# print(parse_table_statement())
-
-
 
 def parse_list(value):
     value = value.asList()
@@ -923,7 +895,7 @@ def parse_list(value):
     # print(f"value: {value}")
     value = strip_sql_quotes(value[0])
     vals = value.split(",")
-    vals = [_strip_any(x,[" "]) for x in vals]
+    vals = [_csu.strip(x,[" "]) for x in vals]
     return ','.join(vals)
 
 def parse_key(value=None):
@@ -1042,9 +1014,6 @@ def parse_constraint(value):
         output = new_data
     return output
 
-
-
-
 def parse_table_columns(sql):
     '''
         Parses an SQL create file into a list of column dictionaries.
@@ -1075,25 +1044,20 @@ def parse_table_columns(sql):
         # @TODO []: documentation for parse_table_columns
     '''
 
-    if _file_exists(sql):
-        sql = _read_file(sql)
-    # orig_sql = sql
+    if _f.exists(sql):
+        sql = _f.readr(sql)
     file_data = strip_keys_constraints(sql)
     file_data['columns'] = {}
-    # file_data['sql'] = '\n'.join([escape_quoted_commas(x) for x in "\n".split(file_data['sql'])])
-    # print(f"file_data['sql']: {file_data['sql']}")
-
-    # sql = parse_primary_keys(sql)
 
     cols = {}
-    parsed = sqlparse.parse(file_data['sql'])
+    parsed = _sqlparse.parse(file_data['sql'])
     for stmt in parsed:
         # Get all the tokens except whitespaces
-        tokens = [t for t in sqlparse.sql.TokenList(stmt.tokens) if t.ttype != sqlparse.tokens.Whitespace]
+        tokens = [t for t in _sqlparse.sql.TokenList(stmt.tokens) if t.ttype != _sqlparse.tokens.Whitespace]
         is_create_stmt = False
         for _, token in enumerate(tokens):
             # Is it a create statements ?
-            if token.match(sqlparse.tokens.DDL, 'CREATE'):
+            if token.match(_sqlparse.tokens.DDL, 'CREATE'):
                 is_create_stmt = True
                 continue
 
@@ -1132,7 +1096,7 @@ def parse_table_columns(sql):
                         "is_primary_key":False,
                     }
                     # print (f"raw_type: {data['raw_type']}")
-                    data['shlexed'] = shlex.split(data['raw_type'])
+                    data['shlexed'] = _shlex.split(data['raw_type'])
                     data = prep_shlexed(data)
                     # print (f"column: {c_name}")
                     if data['name'] in file_data['primary_keys']:
@@ -1152,7 +1116,6 @@ def parse_table_columns(sql):
     # cfu.write.to_json("tmp.sql.delete.json",file_data)
     return file_data
 
-
 def prep_shlexed(col_data):
     '''
         Prepares the shlexed property for parsing by combining indices as necessary.
@@ -1272,9 +1235,9 @@ def parse_col_comment(col_data):
         # s = s.lower()
         # print(f"s: {s}")
         if s.lower().startswith('comment'):
-            # re.replace(r'^comment\s*')
+            # _re.replace(r'^comment\s*')
             cmt = s.replace('comment','')
-            col_data['comment'] = _strip_any(cmt,[" "])
+            col_data['comment'] = _csu.strip(cmt,[" "])
             break
 
     return col_data
@@ -1415,8 +1378,8 @@ def parse_column_size(type_string):
     lower_raw = type_string.lower()
     for sc in sized_cols:
         if sc in lower_raw:
-            pat = re.compile(sc+r"\(([0-9]*)\)")
-            match = re.findall(pat,lower_raw)
+            pat = _re.compile(sc+r"\(([0-9]*)\)")
+            match = _re.findall(pat,lower_raw)
             if match is not None:
                 if len(match) > 0:
                     return int(match[0])
@@ -1440,8 +1403,8 @@ def strip_keys_constraints(sql):
         if is_line_constraint(line):
             output['constraints'].append(line)
             continue
-        # match = re.findall(r'^(\w+\s*)?key',line,re.IGNORECASE)
-        # match = re.findall(r'^((\w+\s*)?key|constraint)',line,re.IGNORECASE)
+        # match = _re.findall(r'^(\w+\s*)?key',line,_re.IGNORECASE)
+        # match = _re.findall(r'^((\w+\s*)?key|constraint)',line,_re.IGNORECASE)
         output['sql'].append(line)
     output['sql'] = '\n'.join(output['sql'])
 
@@ -1469,39 +1432,35 @@ def strip_keys_constraints(sql):
     return output
 
 def is_line_key(line):
-    match = re.match(r'^(\w+\s*)?key',line,re.IGNORECASE)
+    match = _re.match(r'^(\w+\s*)?key',line,_re.IGNORECASE)
     if match is not None:
         return True
     return False
 
 def is_line_comment(line):
-    match = re.match(r'^--',line,re.IGNORECASE)
+    match = _re.match(r'^--',line,_re.IGNORECASE)
     if match is not None:
         return True
     return False
 
-
 def is_line_constraint(line):
-    match = re.match(r'^constraint',line,re.IGNORECASE)
+    match = _re.match(r'^constraint',line,_re.IGNORECASE)
     if match is not None:
         return True
     return False
 
 def parse_primary_keys(sql):
     primary_keys = []
-    match = re.findall(r'primary\s*key\s*\(([a-zA-Z0-9_,\`\'\"\s]*)\)',sql,re.IGNORECASE)
+    match = _re.findall(r'primary\s*key\s*\(([a-zA-Z0-9_,\`\'\"\s]*)\)',sql,_re.IGNORECASE)
     if match is not None:
         if len(match) > 0:
             keys = strip_sql_quotes(match[0])
             keys = keys.split(",")
-            keys = [_strip_any(x,[" "]) for x in keys]
+            keys = [_csu.strip(x,[" "]) for x in keys]
             primary_keys = keys
         # print(match)
     return primary_keys
 
-
-
-
 def format_sql_string(sql):
     '''
         Format an SQL string to a consistent indentation.
@@ -1525,26 +1484,23 @@ def format_sql_string(sql):
         `method_name`: format_sql_string
         @xxx [03-21-2022 12:38:41]: documentation for format_sql_string
     '''
-    if _file_exists(sql):
-        sql = _read_file(sql)
+    if _f.exists(sql):
+        sql = _f.readr(sql)
 
-    sql = _strip_empty_lines(sql)
+    sql = _csu.strip_empty_lines(sql)
 
     raw = sql
-    # raw = re.sub(r'^[\n]*','',raw)
-    statements = sqlparse.split(raw)
+    # raw = _re.sub(r'^[\n]*','',raw)
+    statements = _sqlparse.split(raw)
     new_contents = []
     for state in statements:
-        state = re.sub(r'^[\s\n]*','',state)
-        new_state = sqlparse.format(state, reindent=True, keyword_case='upper')
+        state = _re.sub(r'^[\s\n]*','',state)
+        new_state = _sqlparse.format(state, reindent=True, keyword_case='upper')
         new_contents.append(new_state)
     if len(new_contents) > 0:
         return "\n".join(new_contents)
     return False
 
-
-
-
 def get_statements(sql):
     '''
         Parses the SQL statements from the string.
@@ -1572,13 +1528,13 @@ def get_statements(sql):
 
     raw = sql
     if isinstance(sql,(str)):
-        if _file_exists(sql):
-            raw = _read_file(sql)
+        if _f.exists(sql):
+            raw = _f.readr(sql)
 
     raw = strip_comments(raw)
     raw = escape_quoted_chars(raw)
     # raw = format_sql_string(raw)
-    statements = [x for x in sqlparse.parse(raw)]
+    statements = [x for x in _sqlparse.parse(raw)]
     return statements
 
 def determine_statement_purpose(statement):
@@ -1589,16 +1545,14 @@ def determine_statement_purpose(statement):
 
     return None
 
-
-
 def parse(sql):
-    if _file_exists(sql):
-        sql = _read_file(sql)
+    if _f.exists(sql):
+        sql = _f.readr(sql)
 
     if len(sql)== 0:
         return None
 
-    sql = _strip_empty_lines(sql)
+    sql = _csu.strip_empty_lines(sql)
     raw_statements = get_statements(sql)
     data = {
         "schemas":[],
@@ -1620,7 +1574,7 @@ def parse(sql):
 
         if state['purpose'] == "CREATE TABLE":
             state['data'] = parse_table_statement(state['raw'])
-            _append(data['tables'],state['data'])
+            _lu.append(data['tables'],state['data'])
             continue
 
         # if state['purpose'] == "DROP TABLE":
@@ -1628,7 +1582,7 @@ def parse(sql):
 
         if state['purpose'] == "CREATE SCHEMA":
             state['data'] = parse_schema_statement(state['raw'])
-            _append(data['schemas'],state['data'])
+            _lu.append(data['schemas'],state['data'])
             continue
 
         data['statements'].append(state)
@@ -1641,31 +1595,8 @@ def parse(sql):
 
 
 
-# class Parse:
-#     def __init__(self,**kwargs):
-#         self.settings = {}
-#         self.data = {
-#             "raw_sql":"",
-#             "file_path":ou.get_kwarg(['file path'],None,(str),**kwargs),
-#         }
 
 
-#     def read(self):
-#         if self.data['file_path'] is not None:
-#             if _file_exists(self.data['file_path']):
-#                 self.data['raw_sql'] = cfu
-
-# # statements = get_statements("_sql_parse_test.sql")
-# # for x in statements:
-# #     print(f"========================")
-# #     print(str(x))
-# # print(statements)
 
 
-# path = "Z:\\Structure\\Ra9\\2022\\22-0018 - equari_server\\database\\idealech_Equari_Management_Database\\activity_logs\\activity_logs.sql"
-# cols = parse_table_columns(path)
-# cfu.write.to_json("colums.delete.json",cols)
 
-# parse_constraint()
-# parse_primary_key()
-# parse_key()
\ No newline at end of file
